@@ -35,7 +35,7 @@ class DocManager(DocManagerBase):
 
     def __init__(self, url, auto_commit_interval=DEFAULT_COMMIT_INTERVAL,
                  unique_key='_id', chunk_size=DEFAULT_MAX_BULK, **kwargs):
-
+        # self.graph = Graph('http://127.0.0.1:7474/db/data')
         self.graph = Graph(url)
         self.auto_commit_interval = auto_commit_interval
         self.unique_key = unique_key
@@ -55,10 +55,19 @@ class DocManager(DocManagerBase):
         doc = self._formatter.format_document(doc)
         builder = NodesAndRelationshipsBuilder(doc,doc_id)
         tx = self.graph.begin()
+        for other_actor in builder.other_postion_list:
+            for statement in other_actor.keys():
+                doubanId = other_actor[statement]['doubanId']
+                ret = self.nodeExist(doubanId)
+                if ret == False:
+                    tx.run(statement, {"parameters": other_actor[statement]})
+                else:
+                    pass
+
         for director in builder.director_list:
             for statement in director.keys():
-                name = director[statement]['actorName']
-                ret = self.nodeExist(name)
+                doubanId = director[statement]['doubanId']
+                ret = self.nodeExist(doubanId)
                 if ret == False:
                     tx.run(statement, {"parameters": director[statement]})
                 else:
@@ -66,8 +75,8 @@ class DocManager(DocManagerBase):
 
         for cast in builder.cast_list:
             for statement in cast.keys():
-                name = cast[statement]['actorName']
-                ret = self.nodeExist(name)
+                doubanId = cast[statement]['doubanId']
+                ret = self.nodeExist(doubanId)
                 if ret == False:
                     tx.run(statement, {"parameters": cast[statement]})
                 else:
@@ -82,6 +91,7 @@ class DocManager(DocManagerBase):
                         program_id = builder.parameters['programId']
                         type = "{" + " program_id:{},count:1".format([program_id]) + "}"
                         tx.run(self.creat_relationship(id, id_, type,program_id))
+
         tx.commit()
 
     def update(self, document_id, update_spec, namespace, timestamp):
@@ -107,9 +117,9 @@ class DocManager(DocManagerBase):
     def handle_command(self, doc, namespace, timestamp):
         db = namespace.split('.', 1)[0]
 
-    def nodeExist(self, name):
+    def nodeExist(self, doubanId):
         matcher = NodeMatcher(self.graph)
-        m = matcher.match().where(actorName=name).first()
+        m = matcher.match().where(doubanId=doubanId).first()
         if m is None:
             return False
         else:
